# coding: utf-8
from distutils.core import setup
setup(
  name = 'gherkin3',
  packages = ['gherkin3'],
  version = '3.0.0',
  description = 'Gherkin parser',
  author = 'Björn Rasmusson',
  author_email = 'cukes@googlegroups.com',
  url = 'https://github.com/cucumber/gherkin-python',
  license = 'MIT',
  download_url = 'https://github.com/cucumber/gherkin-ruby/archive/v3.0.0.tar.gz',
  keywords = ['gherkin', 'cucumber', 'bdd'],
  classifiers = [],
)
